@@ -18,6 +18,15 @@ class WeatherBench(Dataset):
     There is a notebook available at: https://binder.pangeo.io/v2/gh/pangeo-data/WeatherBench/master?filepath=quickstart.ipynb
     """
 
+    home_page = "https://raspstephan.github.io/blog/weatherbench/"
+    citation = """@article{rasp2020weatherbench,
+  title={WeatherBench: A benchmark dataset for data-driven weather forecasting},
+  author={Rasp, Stephan and Dueben, Peter D and Scher, Sebastian and Weyn, Jonathan A and Mouatadid, Soukayna and Thuerey, Nils},
+  journal={arXiv preprint arXiv:2002.00469},
+  year={2020}
+}
+"""
+
     def __init__(self, parameter="geopotential_500", resolution=5.625):
         URL = "https://dataserv.ub.tum.de/s/m1524895/download?path=%2F{resolution}deg%2F{parameter}&files={parameter}_{resolution}deg.zip".format(
             resolution=resolution, parameter=parameter
