@@ -13,18 +13,19 @@ from docutils.parsers.rst import Directive
 
 
 class SourcesDirective(Directive):
-
     def run(self):
 
         from climetlab.sources import list_entries
+
         return [nodes.paragraph(text=x) for x in list_entries()]
 
+
 def setup(app):
 
-    app.add_directive('sources', SourcesDirective)
+    app.add_directive("sources", SourcesDirective)
 
     return {
-        'version': '0.1',
-        'parallel_read_safe': True,
-        'parallel_write_safe': True,
+        "version": "0.1",
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
     }
